# phyjax2d

A jax-based 2d physics library, mainly intended to use for reinforcement learning research.

# License
[Apache LICENSE 2.0](./LICENSE) holds unless otherwise noted.

`vec2d.py` is copied from [PyMunk](pymunk.org) with the license-header as-is.
